--
-- Sneekee Mods - Simple UI and Zone Map Changes
-- Author: Polgara97
--

SneekeeModsConfig = {}

SneekeeModsConfig.AceConfig = {
	name = "Sneekee Mods";
	handler = nil;
	type = "group";
	args = {
		taxGroup = {
			type = "header";
			name = "Zone Map (shift-m map)";
			order = 100;
		};
		mapsize = {
			type = "range";
			name = "Map Size";
			desc = "Adjust the map size. 1 = default";
			descStyle = "inline";
			min = 0.1;
			max = 2;
			step = 0.01;
			set = function(info, val) 
                                SneekeeMods.db.profile.mapsize = val; 
                                SneekeeMods:ChangeMapSize();
                            end;
			get = function(info) return SneekeeMods.db.profile.mapsize end;
			isPercent = true;
			order = 101;
		};
		autoshow = {
			type = "toggle";
			name = "Enable and Always Show (requires reload)";
			desc = "Show Map at All Times";
			descStyle = "inline";
			set = function(info, val) SneekeeMods.db.profile.autoshow = val end;
			get = function(info) return SneekeeMods.db.profile.autoshow end;
			width = "full";
			order = 102;
		};
		bgonly = {
			type = "toggle";
			name = "Show Only in BG (requires reload)";
			desc = "Only automatically show in battlegrounds";
			descStyle = "inline";
			set = function(info, val) SneekeeMods.db.profile.bgonly = val end;
			get = function(info) return SneekeeMods.db.profile.bgonly end;
			width = "full";
			order = 103;
		};
		hideedges = {
			type = "toggle";
			name = "Hide Border";
			desc = "Remove the borders from the map";
			descStyle = "inline";
			set = function(info, val) 
                                SneekeeMods.db.profile.hideedges = val; 
                                SneekeeMods:CheckMapEdges();
                            end;
			get = function(info) return SneekeeMods.db.profile.hideedges end;
			width = "full";
			order = 104;
		};
		hideclose = {
			type = "toggle";
			name = "Hide Close Button";
			desc = "Remove the close button (use shift-m to toggle)";
			descStyle = "inline";
			set = function(info, val) 
                            SneekeeMods.db.profile.hideclose = val; 
                                SneekeeMods:CheckCloseButton();
                            end;
			get = function(info) return SneekeeMods.db.profile.hideclose end;
			width = "full";
			order = 104;
		};

		FPSGroup = {
			type = "header";
			name = "Movable FPS Monitor";
			order = 200;
		};
		fpsmonon = {
			type = "toggle";
			name = "Always Show FPS Monitor (requires reload)";
			desc = "Keep FPS Monitor on screen (use ctrl-r to toggle)";
			descStyle = "inline";
			set = function(info, val) SneekeeMods.db.profile.fpsmonon = val end;
			get = function(info) return SneekeeMods.db.profile.fpsmonon end;
			width = "full";
			order = 201;
		};
		fpsmon = {
			type = "toggle";
			name = "Custom Movable FPS Monitor";
			desc = "Hide Blizz FPS Monitor & Use Custom Movable Monitor";
			descStyle = "inline";
			set = function(info, val) 
                                SneekeeMods.db.profile.fpsmon = val; 
                                SneekeeMods:CheckFPSMonitor();
                            end;
			get = function(info) return SneekeeMods.db.profile.fpsmon end;
			width = "full";
			order = 202;
		};
		fpscolor = {
			type = "toggle";
			name = "Change Color to Grey";
			desc = "Make it grey so it is less intrusive";
			descStyle = "inline";
			set = function(info, val) 
                                SneekeeMods.db.profile.fpscolor = val; 
                                SneekeeMods:CheckFPSColor();
                            end;
			get = function(info) return SneekeeMods.db.profile.fpscolor end;
			width = "full";
			order = 203;
		};

		GryphGroup = {
			type = "header";
			name = "Hide Gryphons";
			order = 300;
		};
		hidegryph = {
			type = "toggle";
			name = "Hide Gryphons";
			desc = "Hide Gryphon end caps on action bars";
			descStyle = "inline";
			set = function(info, val) 
                                SneekeeMods.db.profile.hidegryph = val; 
                                SneekeeMods:CheckGryphons();
                            end;
			get = function(info) return SneekeeMods.db.profile.hidegryph end;
			width = "full";
			order = 301;
		};

		QuestsGroup = {
			type = "header";
			name = "Collapse Quest Tracker";
			order = 400;
		};
		hidequests = {
			type = "toggle";
			name = "Collapse Quest Tracker (requires reload)";
			desc = "Collapse Quest Tracker (Objectives) on Login";
			descStyle = "inline";
			set = function(info, val) SneekeeMods.db.profile.hidequests = val end;
			get = function(info) return SneekeeMods.db.profile.hidequests end;
			width = "full";
			order = 401;
		};

		ButtonsGroup = {
			type = "header";
			name = "Hide Text on Buttons";
			order = 500;
		};
		hidemacro = {
			type = "toggle";
			name = "Hide Macro Names (requires reload)";
			desc = "Hide Macro Names on Action Bar Buttons";
			descStyle = "inline";
			set = function(info, val) SneekeeMods.db.profile.hidemacro = val end;
			get = function(info) return SneekeeMods.db.profile.hidemacro end;
			width = "full";
			order = 501;
		};
		hidekeybinds = {
			type = "toggle";
			name = "Hide Key Binds (requires reload)";
			desc = "Hide Key Binds on Action Bar Buttons";
			descStyle = "inline";
			set = function(info, val) SneekeeMods.db.profile.hidekeybinds = val end;
			get = function(info) return SneekeeMods.db.profile.hidekeybinds end;
			width = "full";
			order = 502;
		};

		ACamGroup = {
			type = "header";
			name = "ActionCam Settings";
			order = 600;
		};
		acamignore = {
			type = "toggle";
			name = "Ignore Custom ActionCam";
			desc = "Ignore ActionCam Settings (leave my stuff alone)";
			descStyle = "inline";
			set = function(info, val) 
                                SneekeeMods.db.profile.acamignore = val; 
                                SneekeeMods:CheckActionCam();
                            end;
			get = function(info) return SneekeeMods.db.profile.acamignore end;
			width = "full";
			order = 601;
		};
		acamon = {
			type = "toggle";
			name = "ActionCam On";
			desc = "Use the ActionCam (You MUST turn off Ignore)";
			descStyle = "inline";
			set = function(info, val) 
                                SneekeeMods.db.profile.acamon = val; 
                                SneekeeMods:CheckActionCam();
                            end;
			get = function(info) return SneekeeMods.db.profile.acamon end;
			width = "full";
			order = 602;
		};
		acambasic = {
			type = "toggle";
			name = "ActionCam Basic";
			desc = "Use the ActionCam Basic (limited) Instead of Full (must turn On above)";
			descStyle = "inline";
			set = function(info, val) 
                                SneekeeMods.db.profile.acambasic = val; 
                                SneekeeMods:CheckActionCam();
                            end;
			get = function(info) return SneekeeMods.db.profile.acambasic end;
			width = "full";
			order = 603;
		};

		GarGroup = {
			type = "header";
			name = "Miscellaneous";
			order = 700;
		};
		snkeopts = {
			type = "description";
			name = " -- Use command '/snke' to open options";
			width = "full";
			order = 701;
		};
		garreport = {
			type = "description";
			name = " -- Use command '/snke gar' to show Garrison Report";
			width = "full";
			order = 702;
		};
	}
}

